@@ -10,7 +10,7 @@ from router import load_handlers
 
 from utility import refresh_config,app_path
 
-def run():
+def run(**kwargs):
     refresh_config('setting.py')
     print 
     print 'ConfigParams:'
@@ -33,6 +33,7 @@ def run():
             "gzip":__conf__.GZIP,
             "cookie_secret":__conf__.COOKIE_SECRET,
             "xsrf_cookies":__conf__.XSRF_COOKIES}
+
     app = tornado.web.Application(handlers,**settings)
     app.listen(__conf__.PORT)
     tornado.ioloop.IOLoop.instance().start()
